==> kylin-scanner_3.2.0.4.orig.tar.gz: kylin-scanner-3.2.0.4/src/about/about.cpp <==
#include "about.h"
#include "ui_about.h"
#include <kylin_system/window_management.hpp>
#include <gsettings.hpp>


AboutDialog::AboutDialog(QWidget *parent)
    : QDialog(parent)
    , ui(new Ui::KYCAboutDialog)
{


    ui->setupUi(this);

    initWindow();

    initLayout();

    initStyle();

    initConnect();
}


void AboutDialog::titlebar_icon_theme_changed()
{
    setWindowIcon(QIcon::fromTheme("kylin-scanner"));
    ui->labelLogo->setPixmap(QIcon::fromTheme("kylin-scanner").pixmap(ui->labelLogo->size()));
    ui->labelIcon->setPixmap(QIcon::fromTheme("kylin-scanner").pixmap(96, 96));
}

void AboutDialog::titlebar_style_changed()
{
    QPalette pal;
    if(!isDarkTheme()){
        // light theme
        pal.setColor(QPalette::Background, QColor("#FFFFFF"));
        ui->labelSupport->setText(tr("Service & Support : ")
                                  + "<a href=\"mailto://support@kylinos.cn\" style=\"color:rgba(0,0,0,1)\">"
                                  + "support@kylinos.cn</a>");

        setPalette(pal);
    } else {
        // dark theme
        setPalette(pal);
        ui->labelSupport->setText(tr("Service & Support : ")
                                  + "<a href=\"mailto://support@kylinos.cn\" style=\"color:rgba(255,255,255,1)\">"
                                  + "support@kylinos.cn</a>");
    }
    ui->labelVersion->setPalette(pal);
//    ui->textEdit->setPalette(pal);
    ui->labelSupport->setPalette(pal);
}

AboutDialog::~AboutDialog()
{
    delete ui;
}

void AboutDialog::initWindow()
{
    kdk::kabase::WindowManagement::setWindowMotifHint(winId());

    setWindowModality(Qt::ApplicationModal);
    setWindowTitle(tr("About"));
    setWindowIcon(QIcon::fromTheme("kylin-scanner"));

    setFixedSize(QSize(420, 448-80));
}

void AboutDialog::initLayout()
{
    QString appVersion = QCoreApplication::applicationVersion();
    ui->labelVersion->setText(tr("Version: " ) + appVersion);

    ui->labelLogo->setPixmap(QIcon::fromTheme("kylin-scanner").pixmap(ui->labelLogo->size()));
    ui->labelIcon->setPixmap(QIcon::fromTheme("kylin-scanner").pixmap(96, 96));

    ui->labelName->setText(tr("Scanner"));
    ui->labelTitle->setText(tr("Scanner"));

    ui->btnClose->setIcon(QIcon::fromTheme("window-close-symbolic"));
    ui->btnClose->setProperty("isWindowButton", 0x2);
    ui->btnClose->setProperty("useIconHighlightEffect", 0x8);
    ui->btnClose->setIconSize(QSize(16, 16));
    ui->btnClose->installEventFilter(this);
    ui->btnClose->setFlat(true);

    ui->labelSupport->setContextMenuPolicy(Qt::NoContextMenu); // no right click menu
}

void AboutDialog::initStyle()
{
    QPalette pal;
    QString text =
        tr("Scanner is an interface-friendly scanner, which could be also used as one-click beautification, intelligent correction and text recognition tools.");

    ui->textEdit->setText(text);
    ui->textEdit->setStyleSheet("background-color:rgba(0,255,255,0)");
    if(!isDarkTheme()){
        // light theme
        pal.setColor(QPalette::Background, QColor("#FFFFFF"));
        ui->labelSupport->setText(tr("Service & Support : ")
                                  + QString("<a href=\"mailto://support@kylinos.cn\" style=\"color:%1\">").arg(pal.windowText().color().name(QColor::HexRgb))
                                  + "support@kylinos.cn</a>");
        setPalette(pal);
    } else {
        // dark theme
        setPalette(pal);
        ui->labelSupport->setText(tr("Service & Support : ")
                                  //+ "<a href=\"mailto://support@kylinos.cn\" style=\"color:rgb(255,255,255)\">"
                                  + QString("<a href=\"mailto://support@kylinos.cn\" style=\"color:%1\">").arg(pal.windowText().color().name(QColor::HexRgb))
                                  + "support@kylinos.cn</a>");
    }
    //setFontStyle();

    ui->labelVersion->setPalette(pal);
//    ui->textEdit->setPalette(pal);
    ui->labelSupport->setPalette(pal);
}
bool AboutDialog::isDarkTheme()
{
    QString systemTheme = kdk::kabase::Gsettings::getSystemTheme().toString();

    if (systemTheme == STYLE_NAME_KEY_DARK || systemTheme == STYLE_NAME_KEY_BLACK) {
        return true;
    } else {
        return false;
    }
}
void AboutDialog::initConnect()
{
    connect(ui->btnClose, SIGNAL(clicked()), this, SLOT(hide()));
    connect(ui->labelSupport, &QLabel::linkActivated, [ = ](QString s) {
        QUrl url(s);
        QDesktopServices::openUrl(url);
    });
    connect(kdk::kabase::Gsettings::getPoint(), &kdk::kabase::Gsettings::systemThemeChange, this, &AboutDialog::titlebar_style_changed);
    connect(kdk::kabase::Gsettings::getPoint(), &kdk::kabase::Gsettings::systemThemeChange, this, &AboutDialog::titlebar_icon_theme_changed);
}

void AboutDialog::setFontStyle()
{
    QFont f = ui->labelTitle->font();
    f.setPixelSize(14);
    ui->labelTitle->setFont(f);

    f.setPixelSize(18);
    ui->labelName->setFont(f);

    f.setPixelSize(14);
    f.setFamily(font().family());

    ui->labelVersion->setFont(f);
    ui->textEdit->setFont(f);
    ui->labelSupport->setFont(f);
}

void AboutDialog::moveCenter()
{
    QScreen *screen = QGuiApplication::primaryScreen ();
    QRect screenRect =  screen->availableGeometry();
    this->move(screenRect.width() / 2, screenRect.height() / 2);
}

==> kylin-scanner_3.2.0.6.tar.gz: kylin-scanner-3.2.0.6/src/about/about.cpp <==
#include "about.h"
#include "ui_about.h"
#include "kabase/Qt/windowmanage.hpp"
#include <gsettings.hpp>


AboutDialog::AboutDialog(QWidget *parent)
    : QDialog(parent)
    , ui(new Ui::KYCAboutDialog)
{


    ui->setupUi(this);

    initWindow();

    initLayout();

    initStyle();

    initConnect();
}


void AboutDialog::titlebar_icon_theme_changed()
{
//    setWindowIcon(QIcon::fromTheme("kylin-scanner"));
//    ui->labelLogo->setPixmap(QIcon::fromTheme("kylin-scanner").pixmap(ui->labelLogo->size()));
//    ui->labelIcon->setPixmap(QIcon::fromTheme("kylin-scanner").pixmap(96, 96));
}

void AboutDialog::titlebar_style_changed()
{
    QPalette pal;
    if(!isDarkTheme()){
        // light theme
        pal.setColor(QPalette::Background, QColor("#FFFFFF"));
        ui->labelSupport->setText(tr("Service & Support : ")
                                  + "<a href=\"mailto://support@kylinos.cn\" style=\"color:rgba(0,0,0,1)\">"
                                  + "support@kylinos.cn</a>");

        setPalette(pal);
    } else {
        // dark theme
        setPalette(pal);
        ui->labelSupport->setText(tr("Service & Support : ")
                                  + "<a href=\"mailto://support@kylinos.cn\" style=\"color:rgba(255,255,255,1)\">"
                                  + "support@kylinos.cn</a>");
    }
    ui->labelVersion->setPalette(pal);
//    ui->textEdit->setPalette(pal);
    ui->labelSupport->setPalette(pal);
}

AboutDialog::~AboutDialog()
{
    delete ui;
}

void AboutDialog::initWindow()
{
    ::kabase::WindowManage::removeHeader(this);

    setWindowModality(Qt::ApplicationModal);
    setWindowTitle(tr("About"));
//    setWindowIcon(QIcon::fromTheme("kylin-scanner"));

    setFixedSize(QSize(420, 448-80));
}

void AboutDialog::initLayout()
{
    QString appVersion = QCoreApplication::applicationVersion();
    ui->labelVersion->setText(tr("Version: " ) + appVersion);
    ui->titleIcon->setIcon(QIcon::fromTheme("kylin-scanner"));
    ui->titleIcon->setFixedSize(30,30);
    ui->titleIcon->setIconSize(QSize(24,24));
    ui->titleIcon->setStyleSheet("QPushButton{border:0px;background:transparent;}");
    ui->bigIcon->setIcon(QIcon::fromTheme("kylin-scanner"));
    ui->bigIcon->setFixedSize(96,96);
    ui->bigIcon->setIconSize(QSize(96,96));
    ui->bigIcon->setStyleSheet("QPushButton{border:0px;background:transparent;}");

    ui->labelName->setText(tr("Scanner"));
    ui->labelTitle->setText(tr("Scanner"));

    ui->btnClose->setIcon(QIcon::fromTheme("window-close-symbolic"));
    ui->btnClose->setProperty("isWindowButton", 0x2);
    ui->btnClose->setProperty("useIconHighlightEffect", 0x8);
    ui->btnClose->setIconSize(QSize(16, 16));
    ui->btnClose->installEventFilter(this);
    ui->btnClose->setFlat(true);

    ui->labelSupport->setContextMenuPolicy(Qt::NoContextMenu); // no right click menu
}

void AboutDialog::initStyle()
{
    QPalette pal;
    QString text =
        tr("Scanner is an interface-friendly scanner, which could be also used as one-click beautification, intelligent correction and text recognition tools.");

    ui->textEdit->setText(text);
    ui->textEdit->setStyleSheet("background-color:rgba(0,255,255,0)");
    if(!isDarkTheme()){
        // light theme
        pal.setColor(QPalette::Background, QColor("#FFFFFF"));
        ui->labelSupport->setText(tr("Service & Support : ")
                                  + QString("<a href=\"mailto://support@kylinos.cn\" style=\"color:%1\">").arg(pal.windowText().color().name(QColor::HexRgb))
                                  + "support@kylinos.cn</a>");
        setPalette(pal);
    } else {
        // dark theme
        setPalette(pal);
        ui->labelSupport->setText(tr("Service & Support : ")
                                  //+ "<a href=\"mailto://support@kylinos.cn\" style=\"color:rgb(255,255,255)\">"
                                  + QString("<a href=\"mailto://support@kylinos.cn\" style=\"color:%1\">").arg(pal.windowText().color().name(QColor::HexRgb))
                                  + "support@kylinos.cn</a>");
    }
    //setFontStyle();

    ui->labelVersion->setPalette(pal);
//    ui->textEdit->setPalette(pal);
    ui->labelSupport->setPalette(pal);
}
bool AboutDialog::isDarkTheme()
{
    QString systemTheme = kdk::kabase::Gsettings::getSystemTheme().toString();

    if (systemTheme == STYLE_NAME_KEY_DARK || systemTheme == STYLE_NAME_KEY_BLACK) {
        return true;
    } else {
        return false;
    }
}
void AboutDialog::initConnect()
{
    connect(ui->btnClose, SIGNAL(clicked()), this, SLOT(hide()));
    connect(ui->labelSupport, &QLabel::linkActivated, [ = ](QString s) {
        QUrl url(s);
        QDesktopServices::openUrl(url);
    });
    connect(kdk::kabase::Gsettings::getPoint(), &kdk::kabase::Gsettings::systemThemeChange, this, &AboutDialog::titlebar_style_changed);
    connect(kdk::kabase::Gsettings::getPoint(), &kdk::kabase::Gsettings::systemThemeChange, this, &AboutDialog::titlebar_icon_theme_changed);
}

void AboutDialog::setFontStyle()
{
    QFont f = ui->labelTitle->font();
    f.setPixelSize(14);
    ui->labelTitle->setFont(f);

    f.setPixelSize(18);
    ui->labelName->setFont(f);

    f.setPixelSize(14);
    f.setFamily(font().family());

    ui->labelVersion->setFont(f);
    ui->textEdit->setFont(f);
    ui->labelSupport->setFont(f);
}

void AboutDialog::moveCenter()
{
    QScreen *screen = QGuiApplication::primaryScreen ();
    QRect screenRect =  screen->availableGeometry();
    this->move(screenRect.width() / 2, screenRect.height() / 2);
}
